Struct google_appengine1::AuthorizedDomain [−][src]
A domain that a user has been authorized to administer. To authorize use of a domain, verify ownership via Webmaster Central (https://www.google.com/webmasters/verification/home).
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<String>
Fully qualified domain name of the domain authorized for use. Example: example.com.
name: Option<String>
Full path to the AuthorizedDomain resource in the API. Example: apps/myapp/authorizedDomains/example.com.@OutputOnly