Struct google_appengine1::EndpointsApiService [−][src]
Cloud Endpoints (https://cloud.google.com/endpoints) configuration. The Endpoints API Service provides tooling for serving Open API and gRPC endpoints via an NGINX proxy.The fields here refer to the name and configuration id of a "service" resource in the Service Management API (https://cloud.google.com/service-management/overview).
This type is not used in any activity, and only used as part of another schema.
Fields
config_id: Option<String>
Endpoints service configuration id as specified by the Service Management API. For example "2016-09-19r1"
name: Option<String>
Endpoints service name which is the name of the "service" resource in the Service Management API. For example "myapi.endpoints.myproject.cloud.goog"