Struct google_appengine1::Entrypoint[][src]

pub struct Entrypoint {
    pub shell: Option<String>,
}

The entrypoint for the application.

This type is not used in any activity, and only used as part of another schema.

Fields

The format should be a shell command that can be fed to bash -c.