Struct google_appengine1::ErrorHandler [−][src]
pub struct ErrorHandler {
pub error_code: Option<String>,
pub mime_type: Option<String>,
pub static_file: Option<String>,
}Custom static error page to be served when an error occurs.
This type is not used in any activity, and only used as part of another schema.
Fields
error_code: Option<String>
Error condition this handler applies to.
mime_type: Option<String>
MIME type of file. Defaults to text/html.
static_file: Option<String>
Static file content to be served for this error.