Struct google_appengine1::HealthCheck [−][src]
pub struct HealthCheck {
pub healthy_threshold: Option<u32>,
pub restart_threshold: Option<u32>,
pub timeout: Option<String>,
pub check_interval: Option<String>,
pub disable_health_check: Option<bool>,
pub host: Option<String>,
pub unhealthy_threshold: Option<u32>,
}Health checking configuration for VM instances. Unhealthy instances are killed and replaced with new instances. Only applicable for instances in App Engine flexible environment.
This type is not used in any activity, and only used as part of another schema.
Fields
healthy_threshold: Option<u32>
Number of consecutive successful health checks required before receiving traffic.
restart_threshold: Option<u32>
Number of consecutive failed health checks required before an instance is restarted.
timeout: Option<String>
Time before the health check is considered failed.
check_interval: Option<String>
Interval between health checks.
disable_health_check: Option<bool>
Whether to explicitly disable health checks for this instance.
host: Option<String>
Host header to send when performing an HTTP health check. Example: "myapp.appspot.com"
unhealthy_threshold: Option<u32>
Number of consecutive failed health checks required before removing traffic.