Struct google_appengine1::ListDomainMappingsResponse [−][src]
pub struct ListDomainMappingsResponse {
pub next_page_token: Option<String>,
pub domain_mappings: Option<Vec<DomainMapping>>,
}Response message for DomainMappings.ListDomainMappings.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- domain mappings list apps (response)
Fields
next_page_token: Option<String>
Continuation token for fetching the next page of results.
domain_mappings: Option<Vec<DomainMapping>>
The domain mappings for the application.