Struct google_appengine1::ListServicesResponse [−][src]
pub struct ListServicesResponse {
pub services: Option<Vec<Service>>,
pub next_page_token: Option<String>,
}Response message for Services.ListServices.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- services list apps (response)
Fields
services: Option<Vec<Service>>
The services belonging to the requested application.
next_page_token: Option<String>
Continuation token for fetching the next page of results.