Struct google_appengine1::Service [−][src]
pub struct Service {
pub id: Option<String>,
pub name: Option<String>,
pub split: Option<TrafficSplit>,
}A Service resource is a logical component of an application that can share state and communicate in a secure fashion with other services. For example, an application that handles customer requests might include separate services to handle tasks such as backend data analysis or API requests from mobile devices. Each service has a collection of versions that define a specific set of code used to implement the functionality of that service.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- services get apps (response)
- services patch apps (request)
Fields
id: Option<String>
Relative name of the service within the application. Example: default.@OutputOnly
name: Option<String>
Full path to the Service resource in the API. Example: apps/myapp/services/default.@OutputOnly
split: Option<TrafficSplit>
Mapping that defines fractional HTTP traffic diversion to different versions within the service.