Struct google_appengine1::UrlDispatchRule [−][src]
pub struct UrlDispatchRule {
pub path: Option<String>,
pub domain: Option<String>,
pub service: Option<String>,
}Rules to match an HTTP request and dispatch that request to a service.
This type is not used in any activity, and only used as part of another schema.
Fields
path: Option<String>
Pathname within the host. Must start with a "/". A single "*" can be included at the end of the path.The sum of the lengths of the domain and path may not exceed 100 characters.
domain: Option<String>
Domain name to match against. The wildcard "" is supported if specified before a period: ".".Defaults to matching all domains: "*".
service: Option<String>
Resource ID of a service in this application that should serve the matched request. The service must already exist. Example: default.