Struct google_appengine1::Entrypoint [−][src]
The entrypoint for the application.
This type is not used in any activity, and only used as part of another schema.
Fields
shell: Option<String>
The format should be a shell command that can be fed to bash -c.